@@ -21,6 +21,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 import contextlib
+from collections.abc import Iterable
 from .types import Image, Tag
 from typing import (
     Any,
@@ -71,16 +72,16 @@ class WaifuAioClient(contextlib.AbstractAsyncContextManager):
         if rt:
             return rt
 
-    def _create_params(self, **kwargs) -> Optional[Dict]:
-        rt = []
+    @staticmethod
+    def _create_params(**kwargs) -> Optional[Dict]:
+        rt = {}
         for k, i in kwargs.items():
-            if isinstance(i, list):
-                for item in i:
-                    rt += self._create_params(**{k: item})
+            if isinstance(i, Iterable):
+                rt.update({k: list(i)})
             elif isinstance(i, Image):
-                rt.append((k, i.file))
+                rt.update({k: i.file})
             elif i or isinstance(i, bool):
-                rt.append((k, str(i)))
+                rt.update({k: str(i)})
         if rt:
             return rt
 
@@ -114,7 +115,7 @@ class WaifuAioClient(contextlib.AbstractAsyncContextManager):
                     f'Error at {infos["detail"][0]["loc"][1]}: {infos["detail"][0]["msg"]}'
                 )
             else:
-                raise APIException(response.status, infos['message'])
+                raise APIException(response.status, infos['detail'])
 
     async def random(
             self,
@@ -159,7 +160,7 @@ class WaifuAioClient(contextlib.AbstractAsyncContextManager):
         headers = self._create_headers(**{'User-Agent': self.appname})
         if full:
             if not token and not self.token:
-                raise NoToken(message="the 'full' query string is only accessible to admins and needs a token")
+                raise NoToken(detail="the 'full' query string is only accessible to admins and needs a token")
             headers.update({'Authorization': f'Bearer {token if token else self.token}'})
         infos = await self._make_request(f"{APIBaseURL}random/", 'get', params=params, headers=headers)
         if raw:
@@ -259,7 +260,7 @@ class WaifuAioClient(contextlib.AbstractAsyncContextManager):
             **{'User-Agent': self.appname, 'Authorization': f'Bearer {token if token else self.token}'})
         return await self._make_request(f"{APIBaseURL}fav/toggle/", 'post', params=params, headers=headers)
 
-    async def info(self, images: List[str],raw=False) -> List[Image]:
+    async def info(self, images: List[str], raw=False) -> List[Image]:
         """Fetch the images' data (as if you were requesting a gallery containing only those images)
         args:
             images : A list of images filenames to provide.
